@@ -7,8 +7,7 @@
   SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef SDSUMMARYWIDGET_H
-#define SDSUMMARYWIDGET_H
+#pragma once
 
 #include <KCalendarCore/Event>
 
@@ -39,7 +38,6 @@ public:
     SDSummaryWidget(KontactInterface::Plugin *plugin, QWidget *parent);
     ~SDSummaryWidget() override;
 
-    Q_REQUIRED_RESULT QStringList configModules() const override;
     void configUpdated();
     void updateSummary(bool force = false) override
     {
@@ -84,4 +82,3 @@ private:
     KHolidays::HolidayRegion *mHolidays = nullptr;
 };
 
-#endif
